@@ -2,7 +2,7 @@
 
 package Games::Nintendo::Mario;
 
-use Carp qw(cluck);
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -26,8 +26,9 @@ change his state.
 =cut
 
 use strict;
+use warnings;
 
-our $VERSION = 0.02;
+use Carp qw(cluck);
 
 sub _names  { qw[Mario Luigi] }
 sub _states { qw[normal] }
