@@ -2,9 +2,12 @@
 
 package Games::Nintendo::Mario::SMB;
 
+our $VERSION = '0.10';
+
 use base qw(Games::Nintendo::Mario);
 
-our $VERSION = 0.01;
+use strict;
+use warnings;
 
 sub _names  { qw[Mario Luigi] }
 sub _states { qw[normal super fire] }
@@ -70,6 +73,16 @@ The plumber's state may be any of: C<normal>, C<super>, or C<fire>
 
 Valid powerups are: C<mushroom> and C<flower>
 
+=head1 METHODS
+
+=over 4
+
+=item C<games>
+
+This ruleset reflects Mario in Super Mario Bros., the original SMB game.
+
+=back
+
 =head1 AUTHORS
 
 Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
