@@ -2,9 +2,12 @@
 
 package Games::Nintendo::Mario::SMB3;
 
+our $VERSION = '0.10';
+
 use base qw(Games::Nintendo::Mario);
 
-our $VERSION = 0.01;
+use strict;
+use warnings;
 
 sub _names  { qw[Mario Luigi] }
 sub _states { qw[normal super fire raccoon tanooki frog hammer pwing] }
@@ -78,6 +81,17 @@ C<tanooki>, C<hammer>, C<frog>, or C<pwing>
 Valid powerups are: C<mushroom>, C<flower>, C<leaf>, C<tanookisuit>,
 C<hammersuit>, C<frogsuit>, or C<pwing>
 
+=head1 METHODS
+
+=over 4
+
+=item C<games>
+
+This ruleset reflects Mario in Super Mario Bros. 3.
+
+=back
+
+
 =head1 AUTHORS
 
 Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
